@@ -34,9 +34,8 @@ def is_typed_dict(value: Any, typed_dict: Type[TypedDict]) -> bool:
 def is_decimal(input_string: str) -> bool:
     exceptions = (ValueError, AttributeError, IndexError, TypeError)
     try:
-        number = float(input_string)
-        fraction_length = len(input_string.split('.')[1])
-        is_float = input_string == str(format(number, f'.{fraction_length}f'))
+        float(input_string)
+        is_float = True
     except exceptions:
         is_float = False
 
@@ -100,12 +99,20 @@ class _MultiCaseDict(UserDict):
             if isinstance(value, _Mapping | _MultiCaseDict):
                 for nested_key, nested_value in value.items():
                     if isinstance(nested_value, _Mapping | _MultiCaseDict):
-                        value[nested_key] = cls.recursive_case(nested_value, case_handler)
+                        value[nested_key] = cls.recursive_case(
+                            nested_value,
+                            case_handler,
+                            translate_numbers=translate_numbers
+                        )
 
-                new_dict[key] = cls(value, case_handler, translate_numbers=translate_numbers)
+                new_dict[key] = cls(
+                    value,
+                    case_handler,
+                    translate_numbers=translate_numbers
+                )
             elif isinstance(value, list):
                 new_dict[key] = [
-                    cls.recursive_case(item, case_handler)
+                    cls.recursive_case(item, case_handler, translate_numbers=translate_numbers)
                     if isinstance(item, _Mapping)
                     else item for item in value
                 ]
